@@ -43,6 +43,8 @@ def ManagerMock(manager, *return_value):
     m.model = model
     m.get_query_set = make_get_query_set(m, actual_model)
     m.get = m.get_query_set().get
+    m.count = m.get_query_set().count
+    m.exists = m.get_query_set().exists
     m.__iter__ = m.get_query_set().__iter__
     m.__getitem__ = m.get_query_set().__getitem__
     return m
